@@ -1,4 +1,4 @@
-# Copyright (c) 2010-2023 Kenshi Muto and Masayoshi Takahashi
+# Copyright (c) 2010-2024 Kenshi Muto and Masayoshi Takahashi
 #
 # This program is free software.
 # You can distribute or modify this program under the terms of
@@ -214,12 +214,17 @@ module ReVIEW
           File.open(File.join(basetmpdir, content.file)) do |f|
             f.each_line do |l|
               l.scan(/url\((.+?)\)/) do |_m|
-                @config['epubmaker']['force_include_images'].push($1.strip)
+                @config['epubmaker']['force_include_images'].push($1.strip.gsub(/\A(['"])(.*)\1\Z/, '\2'))
               end
             end
           end
         end
       end
+
+      if @config['coverimage']
+        @config['epubmaker']['force_include_images'].push(File.join(@config['imagedir'], @config['coverimage']))
+      end
+
       @config['epubmaker']['force_include_images'] = @config['epubmaker']['force_include_images'].compact.sort.uniq
     end
 
@@ -523,7 +528,7 @@ module ReVIEW
     end
 
     def copy_static_file(configname, destdir, destfilename: nil)
-      destfilename ||= @config[configname]
+      destfilename ||= File.basename(@config[configname])
       unless File.exist?(@config[configname])
         error! "#{configname}: #{@config[configname]} is not found."
       end
